==> stix2extensions-1.1.10.tar.gz: stix2extensions-1.1.10/generators/scos/user-agent.py <==
import uuid
import stix2
import os
import shutil

from uuid import UUID

from stix2extensions.user_agent import UserAgent
# create the directories

tmp_directories = [
    "tmp_object_store",
]

for directory in tmp_directories:
    if not os.path.exists(directory):
        os.makedirs(directory)

# define UUID for generating UUIDv5s -- this is the OASIS namespace for SCOs https://github.com/oasis-open/cti-python-stix2/blob/master/stix2/base.py#L29

namespace=UUID("00abedb4-aa42-466c-9c01-fed23315a9b7")

# Create UserAgent SCO

example_UserAgentSCO = UserAgent(
                    id="user-agent--"+ str(uuid.uuid5(namespace, f"Mozilla/5.0 (Linux; Android 11; Lenovo YT-J706X) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/96.0.4664.45 Safari/537.36")),
                    string="Mozilla/5.0 (Linux; Android 11; Lenovo YT-J706X) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/96.0.4664.45 Safari/537.36"
                    )

# Write the objects to the filestore
## https://stix2.readthedocs.io/en/latest/guide/filesystem.html#FileSystemSource

### Creating FileSystemStore and adding MarkingDefinitionSMO for each directory

fs_directories = {
    "tmp_object_store": example_UserAgentSCO
}

for directory, useragent_sco in fs_directories.items():
    fs_store = stix2.FileSystemStore(directory)
    fs_store.add([useragent_sco])

# Now move those files into the standardised locations for easy download

final_directories = [
    "example_objects/scos"
]

for directory in final_directories:
    if not os.path.exists(directory):
        os.makedirs(directory)

shutil.move("tmp_object_store/user-agent/user-agent--" + str(uuid.uuid5(namespace, f"Mozilla/5.0 (Linux; Android 11; Lenovo YT-J706X) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/96.0.4664.45 Safari/537.36")) + ".json", "example_objects/scos/user-agent--" + str(uuid.uuid5(namespace, f"Mozilla/5.0 (Linux; Android 11; Lenovo YT-J706X) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/96.0.4664.45 Safari/537.36")) + ".json")

shutil.rmtree("tmp_object_store")

==> stix2extensions-1.2.0.tar.gz: stix2extensions-1.2.0/generators/scos/user-agent.py <==
import uuid
import stix2
import os
import shutil

from uuid import UUID

from stix2extensions.user_agent import UserAgent
# create the directories

tmp_directories = [
    "tmp_object_store",
]

for directory in tmp_directories:
    if not os.path.exists(directory):
        os.makedirs(directory)

# define UUID for generating UUIDv5s -- this is the OASIS namespace for SCOs https://github.com/oasis-open/cti-python-stix2/blob/master/stix2/base.py#L29

namespace=UUID("00abedb4-aa42-466c-9c01-fed23315a9b7")

# Create UserAgent SCO

example_UserAgentSCO = UserAgent(
                    id="user-agent--"+ str(uuid.uuid5(namespace, f"Mozilla/5.0 (Linux; Android 11; Lenovo YT-J706X) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/96.0.4664.45 Safari/537.36")),
                    value="Mozilla/5.0 (Linux; Android 11; Lenovo YT-J706X) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/96.0.4664.45 Safari/537.36"
                    )

# Write the objects to the filestore
## https://stix2.readthedocs.io/en/latest/guide/filesystem.html#FileSystemSource

### Creating FileSystemStore and adding MarkingDefinitionSMO for each directory

fs_directories = {
    "tmp_object_store": example_UserAgentSCO
}

for directory, useragent_sco in fs_directories.items():
    fs_store = stix2.FileSystemStore(directory)
    fs_store.add([useragent_sco])

# Now move those files into the standardised locations for easy download

final_directories = [
    "example_objects/scos"
]

for directory in final_directories:
    if not os.path.exists(directory):
        os.makedirs(directory)

shutil.move("tmp_object_store/user-agent/user-agent--" + str(uuid.uuid5(namespace, f"Mozilla/5.0 (Linux; Android 11; Lenovo YT-J706X) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/96.0.4664.45 Safari/537.36")) + ".json", "example_objects/scos/user-agent--" + str(uuid.uuid5(namespace, f"Mozilla/5.0 (Linux; Android 11; Lenovo YT-J706X) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/96.0.4664.45 Safari/537.36")) + ".json")

shutil.rmtree("tmp_object_store")
